Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(89)

Unified Diff: components/autofill/content/browser/request_autocomplete_manager.h

Issue 229723002: Better error reasons for rAc (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: android Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/content/browser/request_autocomplete_manager.h
diff --git a/components/autofill/content/browser/request_autocomplete_manager.h b/components/autofill/content/browser/request_autocomplete_manager.h
index 058790f42e8332cbb95931c0e026b9cb0fc9a374..164f31c941e9460f47223fb86151a0d5cdc58189 100644
--- a/components/autofill/content/browser/request_autocomplete_manager.h
+++ b/components/autofill/content/browser/request_autocomplete_manager.h
@@ -7,7 +7,7 @@
#include "base/callback_forward.h"
#include "base/memory/weak_ptr.h"
-#include "third_party/WebKit/public/web/WebFormElement.h"
+#include "components/autofill/core/browser/autofill_manager_delegate.h"
class GURL;
@@ -32,24 +32,18 @@ class RequestAutocompleteManager {
private:
// Tells the renderer that the current interactive autocomplete dialog
// finished with the |result| saying if it was successfull or not, and
// |form_data| containing the filled form data.
void ReturnAutocompleteResult(
- blink::WebFormElement::AutocompleteResult result,
- const FormData& form_data);
+ AutofillManagerDelegate::RequestAutocompleteResult result,
+ const FormStructure* form_structure);
// Shows the requestAutocomplete dialog for |source_url| with data from |form|
// and calls |callback| once the interaction is complete.
void ShowRequestAutocompleteDialog(
const FormData& form,
const GURL& source_url,
- const base::Callback<void(const FormStructure*)>& callback);
-
- // If |result| is not null, derives a FormData object from it and passes it
- // back to the page along an |AutocompleteResultSuccess| result. Otherwise, it
- // passes to the page an empty FormData along an
- // |AutocompleteResultErrorCancel| result.
- void ReturnAutocompleteData(const FormStructure* result);
+ const AutofillManagerDelegate::ResultCallback& callback);
// The autofill driver owns and outlives |this|.
ContentAutofillDriver* const autofill_driver_; // weak.
@@ -32,24 +32,18 @@ class RequestAutocompleteManager {
private:
// Tells the renderer that the current interactive autocomplete dialog
- // finished with the |result| saying if it was successfull or not, and
- // |form_data| containing the filled form data.
+ // finished with the |result| saying if it was successful or not, and
+ // |form_structure| containing the filled form data.
void ReturnAutocompleteResult(

Powered by Google App Engine
This is Rietveld 408576698